/*
WixelSerialExample - sketch to demo serial I/O between Arduino and Wixel 
                     the Wexil (http://www.pololu.com/catalog/product/1337) is
                     a USB Wireless board with many features.
                     This example is to demo the USB-to-Serial app.
                     
                     Connect the Arduino pins WixelPinTX & WixelPinRX to the Wixel:
                     
                     Arduino WixelPinRX <-> Wixel P1_6 (TX)
                     Arduino WinelPinTX <-> Wixel P1_7 (RX)
                     
                     The Arduino the reads bytes from the Wixel and sends them
                     to the Arduino Serial Monitor.
                     
                     It is used with another demo program on the PC which sends
                     data to the Wixel, which sends them to the Arduino.
                     
                     By Michael@oz 21 April 2011
*/
#include <NewSoftSerial.h> // make sure you put the two NewSoftSerial files
                           // in the Library directory

#define WixelPinRX 2     // Connect to Wixel TX pin
#define WixelPinTX 3     // Connect to Wixel RX pin
#define ArduinoLED 13
#define PollTime 15000   // Time for Arduino to send a I'm alive message

unsigned long TimeStamp = 0;
NewSoftSerial Wixel(WixelPinRX, WixelPinTX);  // create a serial object
long ByteCount = 0;
char WixByte;
void setup()
{
  pinMode(ArduinoLED, OUTPUT);
  Wixel.begin(57600);
  Serial.begin(115200);
  Serial.println("Starting Wixel serial redirection");
}

void loop()
{
   // when data is ready
if (Wixel.available()) {
  
   // read byte and send to Serial Monitor
   WixByte = Wixel.read();
   Serial.print(WixByte, BYTE);
   
   // light LED when a byte is received
   digitalWrite(ArduinoLED, HIGH);               
   } else
   digitalWrite(ArduinoLED, LOW); // turn LED off when no data
   
   // Print a dot to show program still running
if (millis()>TimeStamp+PollTime) {
   Serial.println(".");
   TimeStamp = millis();
   }
// let the poor 'duino rest a bit, save every mA save the planet ;)
delay(10);   
}
  
